Each cell's text content becomes one element of the data frame.
Row 1 becomes the first row of the data frame (not used as column names).
To promote the first row to headers use setNames(as.data.frame(tbl), as.data.frame(tbl)[1, ]).
Usage
# S3 method for class 'Table'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)